<h2 class="mt-3">
    {{ _('Freeze') }}
    <button class="text-primary bg-transparent box-shadow-none border-0" onclick='copyElementContent("{{ id }}-anchor")'>
        <i class="fa fa-anchor" aria-hidden="true"></i>
    </button>
    <div id="{{ id }}-anchor" class="hidden d-none">
        {{ full_url ~ '#' ~ id }}
    </div>
</h2>
<button class="btn btn-primary mb-3" onclick="copyTextareaClip('freeze-list')">{{ _('Copy list') }}</button>
<textarea rows="{{ data.freeze.modules|length }}" class="w-100 form-control" id="freeze-list">{{ data.freeze.modules_html }}</textarea>
